@@ -112,10 +112,14 @@ amd64_get_revision(pfm_amd64_config_t *cfg)
         if (cfg->family == 15) {
                 switch (cfg->model >> 4) {
                 case 0:
-                        if (cfg->model == 5 && cfg->stepping < 2)
+                        if (cfg->model == 5 && cfg->stepping < 2) {
                                 rev = PFM_PMU_AMD64_K8_REVB;
-                        if (cfg->model == 4 && cfg->stepping == 0)
+				break;
+                        }
+                        if (cfg->model == 4 && cfg->stepping == 0) {
                                 rev = PFM_PMU_AMD64_K8_REVB;
+				break;
+                        }
                         rev = PFM_PMU_AMD64_K8_REVC;
 			break;
                 case 1:
@@ -278,7 +282,7 @@ void amd64_display_reg(void *this, pfmlib_event_desc_t *e, pfm_amd64_reg_t reg)
 {
 	pfmlib_pmu_t *pmu = this;
 
-	if (IS_FAMILY_10H(pmu))
+	if (IS_FAMILY_10H(pmu) || IS_FAMILY_15H(pmu))
 		__pfm_vbprintf("[0x%"PRIx64" event_sel=0x%x umask=0x%x os=%d usr=%d en=%d int=%d inv=%d edge=%d cnt_mask=%d guest=%d host=%d] %s\n",
 			reg.val,
 			reg.sel_event_mask | (reg.sel_event_mask2 << 8),
@@ -343,6 +347,20 @@ pfm_amd64_detect(void *this)
 	return PFM_SUCCESS;
 }
 
+int
+pfm_amd64_family_detect(void *this)
+{
+	struct pfmlib_pmu *pmu = this;
+	int ret;
+
+	ret = pfm_amd64_detect(this);
+	if (ret != PFM_SUCCESS)
+		return ret;
+
+	ret = pfm_amd64_cfg.revision;
+	return ret == pmu->cpu_family ? PFM_SUCCESS : PFM_ERR_NOTSUPP;
+}
+
 static int
 amd64_add_defaults(void *this, pfmlib_event_desc_t *e, unsigned int msk, uint64_t *umask)
 {
@@ -406,7 +424,6 @@ amd64_add_defaults(void *this, pfmlib_event_desc_t *e, unsigned int msk, uint64_
 int
 pfm_amd64_get_encoding(void *this, pfmlib_event_desc_t *e)
 {
-	pfmlib_pmu_t *pmu = this;
 	const amd64_entry_t *pe = this_pe(this);
 	pfm_amd64_reg_t reg;
 	pfm_event_attr_info_t *a;
@@ -472,14 +489,12 @@ pfm_amd64_get_encoding(void *this, pfmlib_event_desc_t *e)
 			/* there can only be one RAW_UMASK per event */
 
 			/* sanity checks */
-			if (((a->idx & ~0xff) && !IS_FAMILY_10H(pmu))
-			   || ((a->idx & ~0xfff) && IS_FAMILY_10H(pmu))) {
+			if (a->idx & ~0xff) {
 				DPRINT("raw umask is invalid\n");
 				return PFM_ERR_ATTR;
 			}
-			/* override umask and extended umask */
+			/* override umask */
 			umask = a->idx & 0xff;
-			reg.sel_event_mask2 = a->idx >> 8;
 			ugrpmsk = grpmsk;
 
 		} else { /* modifiers */
@@ -526,7 +541,8 @@ pfm_amd64_get_encoding(void *this, pfmlib_event_desc_t *e)
 			reg.sel_os = 1;
 		if (e->dfl_plm & PFM_PLM3)
 			reg.sel_usr = 1;
-		if (IS_FAMILY_10H(this) && e->dfl_plm & PFM_PLMH)
+		if ((IS_FAMILY_10H(this) || IS_FAMILY_15H(this))
+		     && e->dfl_plm & PFM_PLMH)
 			reg.sel_host = 1;
 	}
 
